Retrieves the current Open NY catalog and returns datasets available for use with `chi_pull_dataset()`.
Examples
if (interactive() && curl::has_internet()) {
chi_list_datasets()
}
Retrieves the current Open NY catalog and returns datasets available for use with `chi_pull_dataset()`.
if (interactive() && curl::has_internet()) {
chi_list_datasets()
}